@@ -1,15 +1,15 @@
 #' Sites linking to the site
 #'
-#' 
+#'
 #' @param url  String; Required; valid url
 #' @param start index of result at which to start; default = 0
 #' @param count Number of results to return for this request; Max = 20; Default = 20
 #' @param \dots Additional arguments passed to \code{\link{alexa_GET}}.
-#' 
+#'
 #' @return data.frame with two columns: title (site hostname) and url (specific url)
-#'  
+#'
 #' @export
-#' @references \url{http://docs.aws.amazon.com/AlexaWebInfoService/latest/ApiReference_SitesLinkingInAction.html}
+#' @references \url{https://docs.aws.amazon.com/AlexaWebInfoService/latest/ApiReference_SitesLinkingInAction.html}
 #' @examples \dontrun{
 #' in_links(url = "google.com")
 #' }
@@ -25,7 +25,7 @@ in_links <- function(url = NULL, start = 0, count = 20, ...) {
 
   insite_links_payload <- alexa_GET(query, ...)
 
-  res <- bind_rows(lapply(insite_links_payload$Response$SitesLinkingInResult[[1]][[1]],
+  res <- bind_rows(lapply(insite_links_payload$Response$SitesLinkingInResult$Alexa$SitesLinkingIn,
   	                                  function(x) c(title = x$Title, url =x$Url)))
 
   res
