@@ -1,7 +1,7 @@
 context("Get URL Info.")
 
 test_that("url_info happens successfully", {
-  
+
   skip_on_cran()
 
   token_file <- file("aws.alexa_key", "r")
@@ -10,7 +10,7 @@ test_that("url_info happens successfully", {
   key <- unlist(strsplit(token, ","))[1]
   secret <- unlist(strsplit(token, ","))[2]
   set_secret_key(key, secret)
-  
+
   get_info <- url_info("google.com")
-  expect_that(get_info, is_a("data.frame"))
+  expect_that(get_info, is_a("list"))
 })
